#
# spec file for package libXISF
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} < 1590
%global force_gcc_version 12
%endif

%define sover 0
%define full_sover 0.2.13

Name:           libXISF
Version:        0.2.13
Release:        1.2
Summary:        Library to read/write PixInsight XISF files
License:        GPL-3.0-or-later
URL:            https://gitea.nouspiro.space/nou/libXISF
Source:         https://gitea.nouspiro.space/nou/libXISF/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         fix-pkgconfig.patch
BuildRequires:  cmake
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 12
BuildRequires:  liblz4-devel
BuildRequires:  libzstd-devel
BuildRequires:  pkg-config
BuildRequires:  pugixml-devel
BuildRequires:  zlib-devel
BuildRequires:  cmake(Qt5Core) >= 5.14.0

%description
C++ library that can read and write XISF files produced by PixInsight.

%package -n %{name}%{sover}
Summary:        Library to read/write PixInsight XISF files

%description -n %{name}%{sover}
C++ library that can read and write XISF files produced by PixInsight.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{sover} = %{version}

%description devel
This package contains all the needed development files to use %{name}.

%prep
%autosetup -p1 -n libxisf

%build
%cmake \
%if 0%{?force_gcc_version}
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-%{?force_gcc_version} \
%endif
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_BUILD_TYPE=release \
    -DLIBDIR=%{_libdir} \
    -DUSE_BUNDLED_LIBS=OFF
%cmake_build

%install
%cmake_install

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%{_libdir}/libXISF.so.%{sover}
%{_libdir}/libXISF.so.%{full_sover}
%license LICENSE

%files devel
%doc README.md
%{_includedir}/libXISF_global.h
%{_includedir}/libxisf.h
%{_libdir}/libXISF.so
%{_libdir}/pkgconfig/libxisf.pc

%changelog
* Mon Feb 10 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.13:
  * Add test for XISFModify
  * Update pugi, lz4 and zlib
* Wed Jul  3 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.12+git5.d00de20:
  * Add new XISFModify class to edit FITSKeywords
  * Make compression level 0-100
  * Fix calculation of compression level for ZSTD
* Wed Mar 27 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.12:
  * Don't use replace to update attachement position
  * Add support for subblocks to handle +2GiB compressed images
  * Fix bug with writing ICCProfile
  * Add F32Matrix and F64Matrix into toString
- Drop fix-projver.patch.
* Tue Jan  9 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.11:
  * Convert aperture and focal length from mm to meters.
  * Fix not loading String properties.
- Add fix-projver.patch.
* Wed Oct 18 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.10:
  * Fix incorrect header size.
* Thu Oct  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Use better GCC macro.
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.9:
  * Support for ZSTD
* Wed Jun 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.8:
  * Remove linking against zstd
- Drop 6028354c61d230bf2ee85d90cef5d1464da9c5a1.patch
* Tue Jun 13 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.7:
  * Fix reading ICCprofile
- Add 6028354c61d230bf2ee85d90cef5d1464da9c5a1.patch
* Sun Jun  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.6:
  * Fix "string sub-command REPLACE requires at least four arguments"
  * Fix generating pkgconfig file
- Rebase patch
* Thu May 25 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.5:
  * Add method to for ICC profile
  * Add StreamBuffer to optimize save/load from memory
  * Add support for thumbnail
- Add fix-pkgconfig.patch
* Wed Apr 12 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.3:
  * Fix issue with ColorFilterArray.
* Mon Mar 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.1 (no changelog).
* Tue Mar 14 2023 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for descriptions. Avoid miniscule main package
  by moving documentation to subpackages.
* Tue Mar 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Disable hwcaps.
* Mon Mar 13 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.2.0 (no changelog).
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Build AVX2 enabled hwcaps library for x86_64-v3
* Mon Feb 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.1.3:
  * Fix that compression override would produce incorrect images
  * Write pixelStorage attribute
  * Write ICCProfile
- Add fix-projver.patch
* Fri Feb 10 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.1.2:
  * Add readPixel param to getImage()
  * Add option to disable shared lib
* Thu Feb  9 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.1.1:
  * properly set soversion in CMakeLists.txt
- Drop set-sover.patch.
* Wed Feb  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Initial OBS release.
- Add set-sover.patch.
